@@ -1,14 +1,14 @@
 package SPOPS::Secure;
 
-# $Id: Secure.pm,v 1.34 2002/03/05 14:08:07 lachoy Exp $
+# $Id: Secure.pm,v 2.0 2002/03/19 04:00:01 lachoy Exp $
 
 use strict;
-use vars         qw( $EMPTY );
-use Data::Dumper qw( Dumper );
-require Exporter;
+use base  qw( Exporter );
+use vars  qw( $EMPTY );
 
-@SPOPS::Secure::ISA      = qw( Exporter );
-$SPOPS::Secure::VERSION  = substr(q$Revision: 1.34 $, 10);
+use Data::Dumper qw( Dumper );
+
+$SPOPS::Secure::VERSION  = substr(q$Revision: 2.0 $, 10);
 
 # Stuff for security constants and exporting
 
